import { PayloadAction } from '@reduxjs/toolkit';
import { RoomState } from '@zocks-communications/client-sdk-js';
import { RootState } from '../../app/store';
import { ParticipantModel, ParticipantTracksView, SessionModel, TrackView } from '../../models';
import { AddRemoteParticipantAction, ConnectionQualityAction, LocalTrackPublishedAction, LocalTrackUnPublishedAction, RemoveRemoteParticipantAction, TrackMuteAction, TrackSubscribeAction, TrackUnPublishedAction } from './models';
export declare const sessionSlice: import("@reduxjs/toolkit").Slice<SessionModel, {
    setRoomState: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<RoomState>) => void;
    setSessionId: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<string>) => void;
    setConnecting: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<boolean>) => void;
    clearSessionId: (state: import("immer/dist/internal").WritableDraft<SessionModel>) => void;
    setLocalParticipantId: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<string>) => void;
    setLocalParticipantName: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<string | undefined>) => void;
    clearParticipants: (state: import("immer/dist/internal").WritableDraft<SessionModel>) => void;
    participantLocalTrackPublished: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<LocalTrackPublishedAction>) => void;
    participantLocalTrackUnPublished: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<LocalTrackUnPublishedAction>) => void;
    addRemoteParticipant: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<AddRemoteParticipantAction>) => void;
    removeRemoteParticipant: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<RemoveRemoteParticipantAction>) => void;
    subscribeToParticipantTrack: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<TrackSubscribeAction>) => void;
    participantTrackUnPublished: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<TrackUnPublishedAction>) => void;
    participantTrackMuted: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<TrackMuteAction>) => void;
    participantTrackUnMuted: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<TrackMuteAction>) => void;
    connectionQualityChanged: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<ConnectionQualityAction>) => void;
    setActiveSpeakers: (state: import("immer/dist/internal").WritableDraft<SessionModel>, action: PayloadAction<string[]>) => void;
}, "session">;
export declare const setRoomState: import("@reduxjs/toolkit").ActionCreatorWithPayload<RoomState, string>, setSessionId: import("@reduxjs/toolkit").ActionCreatorWithPayload<string, string>, setConnecting: import("@reduxjs/toolkit").ActionCreatorWithPayload<boolean, string>, clearSessionId: import("@reduxjs/toolkit").ActionCreatorWithoutPayload<string>, setLocalParticipantId: import("@reduxjs/toolkit").ActionCreatorWithPayload<string, string>, setLocalParticipantName: import("@reduxjs/toolkit").ActionCreatorWithOptionalPayload<string | undefined, string>, participantLocalTrackPublished: import("@reduxjs/toolkit").ActionCreatorWithPayload<LocalTrackPublishedAction, string>, participantLocalTrackUnPublished: import("@reduxjs/toolkit").ActionCreatorWithPayload<LocalTrackUnPublishedAction, string>, addRemoteParticipant: import("@reduxjs/toolkit").ActionCreatorWithPayload<AddRemoteParticipantAction, string>, removeRemoteParticipant: import("@reduxjs/toolkit").ActionCreatorWithPayload<RemoveRemoteParticipantAction, string>, clearParticipants: import("@reduxjs/toolkit").ActionCreatorWithoutPayload<string>, subscribeToParticipantTrack: import("@reduxjs/toolkit").ActionCreatorWithPayload<TrackSubscribeAction, string>, participantTrackMuted: import("@reduxjs/toolkit").ActionCreatorWithPayload<TrackMuteAction, string>, participantTrackUnMuted: import("@reduxjs/toolkit").ActionCreatorWithPayload<TrackMuteAction, string>, participantTrackUnPublished: import("@reduxjs/toolkit").ActionCreatorWithPayload<TrackUnPublishedAction, string>, connectionQualityChanged: import("@reduxjs/toolkit").ActionCreatorWithPayload<ConnectionQualityAction, string>, setActiveSpeakers: import("@reduxjs/toolkit").ActionCreatorWithPayload<string[], string>;
export declare const selectSessionId: (state: RootState) => string | null;
export declare const selectRoomState: (state: RootState) => RoomState;
export declare const selectIsConnecting: (state: RootState) => boolean;
export declare const selectLocalParticipant: (state: RootState) => ParticipantModel;
export declare const selectActiveSpeakers: (state: RootState) => string[];
export declare const selectRemoteParticipants: ((state: {}) => ParticipantModel[]) & import("reselect").OutputSelectorFields<(args_0: any) => ParticipantModel[] & {
    clearCache: () => void;
}> & {
    clearCache: () => void;
};
export declare const selectLocalParticipantIsConnected: ((state: {
    session: SessionModel;
    view: import("../view/models").ViewModel;
    chat: import("../chat/models").ChatModel;
}) => boolean) & import("reselect").OutputSelectorFields<(args_0: RoomState, args_1: ParticipantModel) => boolean & {
    clearCache: () => void;
}> & {
    clearCache: () => void;
};
export declare const selectIsScreenSharing: ((state: {
    session: SessionModel;
    view: import("../view/models").ViewModel;
    chat: import("../chat/models").ChatModel;
}) => boolean) & import("reselect").OutputSelectorFields<(args_0: ParticipantModel, args_1: ParticipantModel[]) => boolean & {
    clearCache: () => void;
}> & {
    clearCache: () => void;
};
export declare const selectScreenSharingParticipant: ((state: {
    session: SessionModel;
    view: import("../view/models").ViewModel;
    chat: import("../chat/models").ChatModel;
}) => ParticipantModel | null) & import("reselect").OutputSelectorFields<(args_0: ParticipantModel, args_1: any) => ParticipantModel & {
    clearCache: () => void;
}> & {
    clearCache: () => void;
};
export declare const selectSpeakingRemoteParticipantAudioTracks: ((state: {
    session: SessionModel;
    view: import("../view/models").ViewModel;
    chat: import("../chat/models").ChatModel;
}) => TrackView[]) & import("reselect").OutputSelectorFields<(args_0: string | null, args_1: RoomState, args_2: any) => TrackView[] & {
    clearCache: () => void;
}> & {
    clearCache: () => void;
};
export declare const selectTracksForParticipant: ((state: {
    session: SessionModel;
    view: import("../view/models").ViewModel;
    chat: import("../chat/models").ChatModel;
}, params_0: {}) => ParticipantTracksView) & import("reselect").OutputSelectorFields<(args_0: string | null, args_1: RoomState, args_2: any) => ParticipantTracksView & {
    clearCache: () => void;
}> & {
    clearCache: () => void;
};
declare const _default: import("redux").Reducer<SessionModel, import("redux").AnyAction>;
export default _default;
