import React from 'react'
import classNames from 'classnames'
import Linkify from 'linkify-react'
import { ChatMessageElementProps } from '../models'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { ChatMessageAttachment } from './ChatMessageAttachment'
import './ChatMessage.scss'

const linkifyOptions = {
  defaultProtocol: 'https',
  target: '_blank',
}

export const ChatMessage: React.FC<ChatMessageElementProps> = ({
  chatMessage,
  getAttachmentLocation,
  sameThreadAsPrevious,
  localParticipantLabel = 'Me',
  chatMessageAttachmentElement,
}) => {
  const { id: localParticipantId } = useZocksStore(selectLocalParticipant)
  const {
    from: { id: senderId, name: senderName },
    to: { id: recipientId, name: recipientName } = {},
    message,
    attachment,
  } = chatMessage

  const sentByMe = senderId === localParticipantId
  const forMe = recipientId === localParticipantId
  const directMessage = !!recipientId

  const headerText =
    `${sentByMe ? localParticipantLabel : senderName}` +
    (directMessage ? ` To ${forMe ? localParticipantLabel : recipientName}` : '')

  const ChatMessageAttachmentElement = chatMessageAttachmentElement ?? ChatMessageAttachment

  return (
    <div
      className={classNames('chat-message__container', {
        'chat-message__container--sent': sentByMe,
        'chat-message__container--received': !sentByMe,
      })}
    >
      {!sameThreadAsPrevious && (
        <>
          <div className='chat-message__avatar'>{senderName.slice(0, 1)}</div>
          <div
            className={classNames('chat-message__header', {
              'chat-message__header--public': !directMessage,
              'chat-message__header--private': directMessage,
            })}
          >
            {headerText}
          </div>
        </>
      )}
      {message && (
        <Linkify options={linkifyOptions}>
          <div className='chat-message__message'>{message}</div>
        </Linkify>
      )}
      {attachment && getAttachmentLocation && (
        <ChatMessageAttachmentElement attachment={attachment} getAttachmentLocation={getAttachmentLocation} />
      )}
    </div>
  )
}
