import React from 'react'
import userEvent from '@testing-library/user-event'
import { render, screen } from '@testing-library/react'
import { DeviceSelectButton } from './DeviceSelectButton'
import { setupMediaDevicesMock } from '../../testUtils'

afterEach(() => jest.restoreAllMocks())

test('gathers all devices on render and sets up an event listener for plugged in devices', async () => {
  const { mockGetDevices, mockNavigatorMediaDevices } = setupMediaDevicesMock()
  const { unmount } = render(
    <DeviceSelectButton deviceKind={'audioinput'} onDeviceSelected={jest.fn()} className='test' />
  )

  userEvent.click(screen.getByRole('button'))
  expect(await screen.findByText('Test Microphone 1')).toBeInTheDocument()

  expect(mockGetDevices).toHaveBeenCalledTimes(1)
  expect(mockNavigatorMediaDevices.addEventListener).toHaveBeenCalledTimes(1)
  expect(mockNavigatorMediaDevices.addEventListener).toHaveBeenCalledWith('devicechange', expect.any(Function))
  expect(mockGetDevices).toHaveBeenCalledTimes(1)
  expect(mockGetDevices).toHaveBeenCalledWith('audioinput')
  unmount()
  expect(mockNavigatorMediaDevices.removeEventListener).toHaveBeenCalledTimes(1)
  expect(mockNavigatorMediaDevices.removeEventListener).toHaveBeenCalledWith('devicechange', expect.any(Function))
})

test('calls the onDeviceSelected callback with the media info of the device when selecting a device', async () => {
  setupMediaDevicesMock()
  const mockOnDeviceSelected = jest.fn()
  render(<DeviceSelectButton deviceKind={'audioinput'} onDeviceSelected={mockOnDeviceSelected} />)
  userEvent.click(screen.getByRole('button'))
  expect(await screen.findByText('Test Microphone 1')).toBeInTheDocument()

  userEvent.click(screen.getByText('Test Microphone 1'))

  expect(mockOnDeviceSelected).toHaveBeenCalledTimes(1)
  expect(mockOnDeviceSelected).toHaveBeenCalledWith({
    deviceId: 'testMicrophone1MediaDeviceId',
    label: 'Test Microphone 1',
    kind: 'audioinput',
    groupId: 'test',
    toJSON: expect.any(Function),
  })
})
