import React from 'react'
import { ParticipantsGridView } from '../ParticipantsGridView'
import { ParticipantsSpeakerView } from '../ParticipantsSpeakerView'
import { useZocksStore } from '../../../app'
import { ParticipantsViewType, selectCurrentParticipantsView, selectIsScreenSharing } from '../../../store'
import { ParticipantsScreenShareView } from '../ParticipantsScreenShareView'
import { ParticipantAudio } from '../ParticipantAudio'
import './Participants.scss'

export const Participants: React.FC<{ gridPageSize?: number; speakerPageSize?: number }> = ({
  gridPageSize = 25,
  speakerPageSize = 4,
}) => {
  const isScreenSharing = useZocksStore(selectIsScreenSharing)
  const currentView = useZocksStore(selectCurrentParticipantsView)

  const getCurrentView = () => {
    switch (true) {
      case isScreenSharing:
        return <ParticipantsScreenShareView />
      case currentView === ParticipantsViewType.Grid:
        return <ParticipantsGridView pageSize={gridPageSize} />
      case currentView === ParticipantsViewType.Speaker:
        return <ParticipantsSpeakerView pageSize={speakerPageSize} />
    }
  }

  return (
    <div className='participants'>
      {getCurrentView()}
      <ParticipantAudio />
    </div>
  )
}
