import { useZocksStore } from '../../app'
import { selectIsScreenSharing, selectLocalParticipant, selectScreenSharingParticipant } from '../../store'
import { ZocksMediaActions } from '../../models'

export const useRoomControls = (mediaActions: ZocksMediaActions) => {
  const { publishAudio, publishVideo, unPublishAudio, unPublishVideo, switchActiveDevice } = mediaActions
  const localParticipant = useZocksStore(selectLocalParticipant)
  const isScreenSharing = useZocksStore(selectIsScreenSharing)
  const screenSharingParticipant = useZocksStore(selectScreenSharingParticipant)
  const isLocalScreenShare = screenSharingParticipant === localParticipant
  const audioIsOn = !!(localParticipant.tracks.audioTracks.length && !localParticipant.tracks.audioTracks[0].isMuted)
  const videoIsOn = !!(localParticipant.tracks.videoTracks.length && !localParticipant.tracks.videoTracks[0].isMuted)

  const toggleAudio = () => {
    if (audioIsOn) {
      unPublishAudio()
    } else {
      publishAudio()
    }
  }

  const toggleVideo = () => {
    if (videoIsOn) {
      unPublishVideo()
    } else {
      publishVideo()
    }
  }

  const selectAudioDevice = (audioDevice: MediaDeviceInfo) => {
    switchActiveDevice('audioinput', audioDevice.deviceId)
  }
  const selectVideoDevice = (videoDevice: MediaDeviceInfo) => {
    switchActiveDevice('videoinput', videoDevice.deviceId)
  }

  return {
    audioIsOn,
    videoIsOn,
    isScreenSharing,
    isLocalScreenShare,
    toggleAudio,
    toggleVideo,
    selectAudioDevice,
    selectVideoDevice,
  }
}
