import React, { useState } from 'react'
import ReactDOM from 'react-dom'
import { RoomInfo } from '@zocks-communications/client-sdk-js'
import { useLeaveOnUnload, useZocksActions, useZocksSession } from '../../store'
import { JoinPage, Participants, RoomControls } from '../../components'
import { Chat, ViewSwitcher } from '../../components'
import { OnlineParticipantsList } from '../../components'
import { ZocksConfig } from '../../app/zocksConfig'
import './Meeting.scss'
import { ChatInputElementProps, CustomizableChatInput } from '../../components'

export const zocksConfig: ZocksConfig = {
  // apiBaseUrl: 'http://localhost:8000/v1',
  apiBaseUrl: 'https://dev-api.zocks.io/v1',
  accountId: '0y0ca2wqgr4ugypm',
  logLevel: 'debug',
}

const ChatInputWithoutEmojiSelector: React.FC<ChatInputElementProps> = ({
  remoteParticipants,
  sendPublicMessage,
  sendPrivateMessage,
  uploadAttachment,
}) => {
  return (
    <CustomizableChatInput
      remoteParticipants={remoteParticipants}
      sendPublicMessage={sendPublicMessage}
      sendPrivateMessage={sendPrivateMessage}
      uploadAttachment={uploadAttachment}
      emojiSelectorElement={() => null}
    />
  )
}

export const Meeting = () => {
  const { sessionActions, localMediaActions, chatActions } = useZocksActions(zocksConfig)
  const { sessionId, localParticipantIsConnected } = useZocksSession()
  useLeaveOnUnload(sessionActions.leave)

  const [showParticipantsList, setShowParticipantsList] = useState(false)
  const [showChat, setShowChat] = useState(false)
  const [newRoom, setNewRoom] = useState<RoomInfo | null>(null)

  return (
    <div className='meeting'>
      <h1>Example</h1>
      <div>{'Session id: ' + sessionId}</div>
      <div>{'Connected: ' + localParticipantIsConnected}</div>

      {!localParticipantIsConnected ? (
        <>
          <JoinPage
            createRoomAction={sessionActions.createRoom}
            joinAction={sessionActions.join}
            onNewRoomCreated={(roomInfo) => setNewRoom(roomInfo)}
          />
          {newRoom && <div>{`New room created: ${JSON.stringify(newRoom)}`}</div>}
        </>
      ) : (
        <React.Fragment>
          <div className='meeting__participants-list' id='participants-list-root' />
          <div className='meeting__chat' id='chat-root' />
          {showParticipantsList &&
            ReactDOM.createPortal(
              <OnlineParticipantsList dismiss={() => setShowParticipantsList(false)} />,
              document.getElementById('participants-list-root')!
            )}
          {showChat &&
            ReactDOM.createPortal(
              <Chat
                chatActions={chatActions}
                dismiss={() => setShowChat(false)}
                chatInputElement={ChatInputWithoutEmojiSelector}
              />,
              document.getElementById('chat-root')!
            )}
          <RoomControls mediaActions={localMediaActions} leaveAction={sessionActions.leave} />
          <ViewSwitcher />
          <Participants speakerPageSize={4} />
          <div className='meeting__participants-list-button-container'>
            <button
              className='meeting__participants-list-button'
              disabled={showParticipantsList}
              onClick={() => setShowParticipantsList(true)}
            >
              Show Participants
            </button>
          </div>
          <div className='meeting__chat-button-container'>
            <button className='meeting__chat-button' disabled={showChat} onClick={() => setShowChat(true)}>
              Show Chat
            </button>
          </div>
        </React.Fragment>
      )}
    </div>
  )
}
