import { ConnectionQuality, RoomInfo, RoomState, Session, Track } from '@zocks-communications/client-sdk-js'
import { ChatAttachmentModel } from './store/chat/models'

export interface StreamModel {
  id: string
  isMuted: boolean
}

export interface TrackModel extends StreamModel {}

export interface ParticipantModel {
  id: string | null
  name: string | null
  tracks: {
    videoTracks: TrackModel[]
    audioTracks: TrackModel[]
    screenShareTrack: TrackModel | null
  }
  connectionQuality: ConnectionQuality
}

export interface TrackView {
  readonly track: Track
  readonly isMuted: boolean
}

export interface ParticipantTracksView {
  readonly videoTracks: TrackView[]
  readonly audioTracks: TrackView[]
  readonly primaryVideoTrack: TrackView | null
  readonly primaryAudioTrack: TrackView | null
  readonly screenShareTrack: TrackView | null
}

export interface ParticipantView {
  readonly id: string | null
  readonly name: string | null
  readonly tracks: ParticipantTracksView
  readonly isLocal: boolean
  readonly connectionQuality: ConnectionQuality
  readonly isSpeaking: boolean
}

export interface SessionModel {
  sessionId: string | null
  roomState: RoomState
  isConnecting: boolean
  localParticipant: ParticipantModel
  remoteParticipants: { [id: string]: ParticipantModel }
  activeSpeakers: string[]
}

export interface SessionView {
  readonly sessionId: string | null
  readonly roomState: RoomState
  readonly isConnecting: boolean
  readonly localParticipant: ParticipantModel
  readonly remoteParticipants: ParticipantModel[]
  readonly localParticipantIsConnected: boolean
}

export interface JoinOptions {
  readonly roomId: string
  readonly autoCreate: boolean
  readonly audioDeviceSettings?: MediaTrackSettings
  readonly videoDeviceSettings?: MediaTrackSettings
  readonly afterJoinCallback?: () => void
  readonly joinErrorCallback?: (e: Error) => void
}

export interface ZocksSessionActions {
  createRoom: () => Promise<RoomInfo>
  join: (joinOptions: JoinOptions) => void
  leave: () => void
}

export interface ZocksMediaActions {
  publishVideo: (mediaTrackSettings?: MediaTrackSettings) => void
  unPublishVideo: (mediaTrackSettings?: MediaTrackSettings) => void
  publishAudio: (mediaTrackSettings?: MediaTrackSettings) => void
  unPublishAudio: (mediaTrackSettings?: MediaTrackSettings) => void
  publishScreenShare: () => void
  unPublishScreenShare: () => void
  switchActiveDevice: (kind: MediaDeviceKind, deviceId: string) => void
}

export interface ZocksChatActions {
  sendPublicMessage: (message: string, attachment?: ChatAttachmentModel) => void
  sendPrivateMessage: (message: string, remoteParticipant: ParticipantModel, attachment?: ChatAttachmentModel) => void
  uploadAttachment: (file: File, remoteParticipant?: ParticipantModel) => Promise<string | undefined>
  getAttachmentLocation: (attachmentFileId: string) => Promise<string | undefined>
}

export interface ZocksActions {
  session?: Session
  sessionActions: ZocksSessionActions
  localMediaActions: ZocksMediaActions
  chatActions: ZocksChatActions
}
