import { createSlice, PayloadAction } from '@reduxjs/toolkit'
import { RootState } from '../../app/store'
import { ChatMessageAction, ChatMessageModel, ChatMessageType, ChatModel } from './models'

const initialState: ChatModel = {
  publicChatMessages: [],
  privateChatMessages: {},
}

export const chatSlice = createSlice({
  name: 'chat',
  initialState,
  reducers: {
    savePublicChatMessage: (state, action: PayloadAction<ChatMessageAction>) => {
      const chatMessage = action.payload
      state.publicChatMessages.push({
        type: ChatMessageType.PUBLIC,
        ...chatMessage,
      })
    },
    privateChatMessageReceived: (state, action: PayloadAction<ChatMessageAction>) => {
      const chatMessage = action.payload
      const { privateChatMessages } = state
      const {
        from: { id: senderId },
      } = chatMessage
      addPrivateMessageForParticipant(privateChatMessages, chatMessage, senderId)
    },
    privateChatMessageSent: (state, action: PayloadAction<ChatMessageAction>) => {
      const chatMessage = action.payload
      const { privateChatMessages } = state
      const { to: { id: recipientId } = {} } = chatMessage
      addPrivateMessageForParticipant(privateChatMessages, chatMessage, recipientId)
    },
    clearChatMessages: (state) => {
      state.publicChatMessages = []
      state.privateChatMessages = {}
    },
  },
})

const addPrivateMessageForParticipant = (
  privateChatMessages: { [participantId: string]: ChatMessageModel[] },
  chatMessage: ChatMessageAction,
  remoteParticipantId?: string
) => {
  if (!remoteParticipantId) {
    return
  }
  if (!Object.keys(privateChatMessages).includes(remoteParticipantId)) {
    privateChatMessages[remoteParticipantId] = []
  }
  privateChatMessages[remoteParticipantId].push({
    type: ChatMessageType.PRIVATE,
    ...chatMessage,
  })
}

export const { savePublicChatMessage, privateChatMessageReceived, privateChatMessageSent, clearChatMessages } =
  chatSlice.actions

export const selectPublicChatMessages = (state: RootState) => state.chat.publicChatMessages

export const selectPrivateChatMessages = (state: RootState) => state.chat.privateChatMessages

export default chatSlice.reducer
